#!/usr/bin/perl -w
use strict;

my @array = `grep MP3_EXPORT src/*.c`;
print <<EOF;
/*
 * Prototypes
 */

EOF

for (@array) {
	s/^.*://; 
	s/^MP3_EXPORT\((.+)/$1/; 
	s/\)//; 
	s/ {$//; 
	s/{
$//; 
	s/$/;/;
	print $_;
}
